Sign inSign up

bradfordcp/cg_obup

By bradfordcp

•Updated over 8 years ago

Docker container for the CryptoGuru Optimized BURSTcoin Unix Plotter

Image
1

291

bradfordcp/cg_obup repository overview

⁠CryptoGuru Optimized BURSTcoin Unix Plotter Docker Container

Source available at https://github.com/PoC-Consortium/cg_obup⁠

⁠Features
  • Optimized for size (FROM "scratch")
⁠Running

Important notes:

  1. You must bind the directory where plots will be written in to the container
  2. Specify the user and group numeric id with -u so the files are written with the appropriate permissions. Using the text version of the user id and group id will result in an error message. To retrieve the user and group numeric ids run id username.

In the example below my plots are being written under the directory /opt/plot_pools. The user and group burst are used so we include the numeric user id and group id.

docker run -i -t --rm --mount type=bind,source=/opt/plot_pools,destination=/opt/plot_pools -u 997:1001 bradfordcp/cg_obup /plot64 -k account_numeric_key -x 2 -d /opt/plot_pools/pool_2/ -m 32768 -s 53411840 -v -a -t 4 -p 1099511627776
⁠Plot64 Usage
/plot64 -k KEY [-x <core>] [-d <dir>] [-s <startnonce>] [-n <nonces>] [-m <staggersize>] [-t <threads>] [-a]
  -a
    Flag to use asynchronous writing mode. If this is set, the plotter can work
    even while data is being written to disk. It will give you more speed at the
    cost of more memory usage (will use double the memory!). Default is OFF.

  -b <maxmemory>
    Maximum amount of memory to use. Will automatically be halved when used in
    combination with -a.

  -R
    Resume from last position in an existing plot file.
    IMPORTANT: The plot file has to be created with the resume option to make resume work!
               Don't use the resume option if the plot file was created without the resume option!

  -d <directory>
    Which directory to use. You can give relative as well as absolute paths.
    If you omit this, plots are written into the 'plots' directory in the
    current path.

  -f <diskspace>
    When -n is not specified, leave this much disk space while calculating number
    of nonces to plot.

  -m <staggersize>
    In this version, you can think of this as the memory cache used by the program
    before a write to the disk is necessary. Obviously the more you give here, the
    less I/O is necessary. If not given, the program tries to use 80% of the free
    memory of the machine. Please be aware that in combination with the -a parameter
    the memory requirement is doubled!

  -n <nonces|spacedef>
    The number of nonces to plot. Each nonce is 256KB in size. If you do not
    give the number of nonces, the program will try to plot the maximum number
    of nonces that are possible according to the free disk space where
    <directory> resides.

  -p <plotfilesize>
    Attempt to create a plot file of this size. May not be combined with -n, since
    the amount of nonces will be calculated from the file size.

  -s <startnonce>
    The offset from which to start plotting nonces. If not given, the program will
    simply choose an offset randomly.

  -t <threads>
    Number of threads to use when plotting. There is no "more is better".
    Depending on the number of physical cores of your CPU, and the core
    (see below) used, there will be an optimum. Probably the number of physical
    cores your CPU has.

  -v
    Verbose mode.
    
  -x <core>
    Define which SHABAL256 hashing core to use. Possible values are:
      0 - default core (*)
      1 - SSE4 core
      2 - AVX2 core
    Of course, SSE4 and AVX2 will work only on CPU architectures supporting
    these instruction sets. Otherwise the program will throw an "illegal instruction"
    error. You can assume a roughly 2x speed increase default->SSE4->AVX2 with
    AVX2 being roughly 4x faster than default. See also "Notes" below!

Tag summary

Content type

Image

Digest

Size

1019.9 kB

Last updated

over 8 years ago

docker pull bradfordcp/cg_obup